#
# spec file for package libiptcdata
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libiptcdata
Version:        1.0.5
Release:        1.18
Summary:        IPTC Metadata Tag Manipulation Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://github.com/ianw/libiptcdata/
Source:         https://github.com/ianw/libiptcdata/releases/download/release_1_0_5/libiptcdata-%{version}.tar.gz
BuildRequires:  pkgconfig
Requires:       libiptcdata0

%description
libiptcdata is a library for parsing, editing, and saving IPTC
(International Press Telecommunications Council) data. stored within
multimedia files such as images.

%package -n libiptcdata0
Summary:        IPTC Metadata Tag Manipulation Library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n libiptcdata0
libiptcdata is a library for parsing, editing, and saving
International Press
Telecommunications Council (IPTC) metadata stored within multimedia
files such as images. This metadata can include captions and keywords,
often used by popular photo management applications. The library
provides routines for parsing, viewing, modifying, and saving this
metadata. The libiptcdata package also includes a command line utility,
iptc, for editing IPTC data in JPEG files. The library implements the
IPTC Information Interchange Model according to its specification.

%package devel
Summary:        Development files for the IPTC Metadata Tag Manipulation Library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
libiptcdata is a library for parsing, editing, and saving IPTC
(International Press Telecommunications Council) data. stored within
multimedia files such as images.

This subpackage contains the header files for the library.

%package doc
Summary:        Documentation for the IPTC Metadata Tag Manipulation Library
Group:          Documentation/HTML

%description doc
libiptcdata is a library for parsing, editing, and saving IPTC
(International Press Telecommunications Council) data. stored within
multimedia files such as images.

This subpackage contains the documentation for it.

%lang_package

%prep
%setup -q

%build
%configure --disable-static
%make_build

%install
%make_install
%find_lang %{name}
%find_lang iptc %{name}.lang
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libiptcdata0 -p /sbin/ldconfig
%postun -n libiptcdata0 -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog INSTALL NEWS README TODO
%{_bindir}/*

%files -n libiptcdata0
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*

%files doc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/*

%files lang -f %{name}.lang

%changelog
* Sun Sep 13 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.0.5:
  * Omnibus python3 update
  * Modernize autoconf/automake init
  * Update to latest gtk-doc
  * Fix python3 module init
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Mar  5 2018 jengelh@inai.de
- Fix RPM groups. Trim description for secondary packages a bit.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Sun Feb 27 2011 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Wed Apr 28 2010 dimstar@opensuse.org
- BuildRequire pkg-config in order to have pkgconfig() provides.
* Tue Jul 21 2009 lmedinas@gmail.com
- Update to version 1.0.4:
  + Fixed multilib conflict from documentation in -devel rpm
  + Added Italian translation
* Fri Mar 27 2009 vuntz@novell.com
- Update to version 1.0.3:
  + Fix for python saving so it does not fail when /tmp is a
    different filesystem.
  + Fix python crash on unknown datasets.
  + Clean up iptc_dataset_dump output.
  + Added German translation.
- Remove AutoReqProv: it's default now.
- Don't set CFLAGS to the default value.
- Use standard configure, with --disable-static.
- Don't remove $RPM_BUILD_ROOT in install (it's automatically
  done).
- Use makeinstall.
- Remove .la files.
- Create a lang package for translations.
* Fri Feb  1 2008 rodrigo@suse.de
- Update to version 1.0.2:
  * Compatibility improvements for Picasa: The IPTC version and
    encoding are no longer stored by default in saved IPTC output
    because these fields confuse Picasa
  * APP13 data block is stored closer to the beginning of the file
  * Minor Python compile fix
* Mon Oct  8 2007 maw@suse.de
- Split off a libiptcdata0 subpackage
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun.
* Tue Jan 30 2007 ro@suse.de
- GNOME moved to /usr
* Tue Jan 23 2007 ro@suse.de
- drop requires for gnome-filesystem
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- New SuSE package, version 0.2.1.
